@@ -11,10 +11,9 @@ from os.path import join as pjoin
 
 from jupyter_core.paths import SYSTEM_CONFIG_PATH, jupyter_config_dir, jupyter_path
 from jupyter_server.services.config.manager import ConfigManager, recursive_update
+from jupyter_server.utils import url_path_join as ujoin
 from traitlets import Bool, HasTraits, List, Unicode, default
 
-from .server import url_path_join as ujoin
-
 # -----------------------------------------------------------------------------
 # Module globals
 # -----------------------------------------------------------------------------
@@ -79,10 +78,10 @@ def get_static_page_config(app_settings_dir=None, logger=None, level="all"):
     return cm.get("page_config")
 
 
-def get_page_config(labextensions_path, app_settings_dir=None, logger=None):
+def get_page_config(labextensions_path, app_settings_dir=None, logger=None):  # noqa
     """Get the page config for the application handler"""
     # Build up the full page config
-    page_config = {}
+    page_config: dict = {}
 
     disabled_key = "disabledExtensions"
 
@@ -113,7 +112,7 @@ def get_page_config(labextensions_path, app_settings_dir=None, logger=None):
     # Ensure there is a disabled key
     page_config.setdefault(disabled_key, {})
 
-    for (_, ext_data) in federated_exts.items():
+    for _, ext_data in federated_exts.items():
         if "_build" not in ext_data["jupyterlab"]:
             logger.warning("%s is not a valid extension" % ext_data["name"])
             continue
@@ -143,7 +142,7 @@ def get_page_config(labextensions_path, app_settings_dir=None, logger=None):
             with open(package_data_file, encoding="utf-8") as fid:
                 app_data = json.load(fid)
             all_ext_data = app_data["jupyterlab"].get("extensionMetadata", {})
-            for (ext, ext_data) in all_ext_data.items():
+            for ext, ext_data in all_ext_data.items():
                 if ext in disabled_by_extensions_all:
                     continue
                 if ext_data.get(disabled_key):
@@ -164,8 +163,7 @@ def get_page_config(labextensions_path, app_settings_dir=None, logger=None):
     page_config[disabled_key] = rollup_disabled
 
     # Convert dictionaries to lists to give to the front end
-    for (key, value) in page_config.items():
-
+    for key, value in page_config.items():
         if isinstance(value, dict):
             page_config[key] = [subkey for subkey in value if value[subkey]]
 
@@ -321,7 +319,8 @@ def _get_config_manager(level):
     """
     allowed = ["all", "user", "sys_prefix", "system", "app", "extension"]
     if level not in allowed:
-        raise ValueError(f"Page config level must be one of: {allowed}")
+        msg = f"Page config level must be one of: {allowed}"
+        raise ValueError(msg)
 
     config_name = "labconfig"
 
